@@ -6,8 +6,9 @@ from fastapi.templating import Jinja2Templates
 
 from pydantic import BaseModel, validator
 
+from ..__version__ import __version__
 from .. import templates
-from ..downloader import download_url
+from ..downloader import download_package, list_packages
 
 
 router = APIRouter(tags=['server'])
@@ -33,10 +34,13 @@ class JobSubmission(BaseModel):
 
 @router.get('/', response_class=HTMLResponse)
 async def root(request: Request):
-    return templates.TemplateResponse('index.html', {'request': request})
+    return templates.TemplateResponse(
+        'index.html',
+        {'request': request, 'version': __version__, 'package_list': list_packages()},
+    )
 
 
 @router.post('/submit_job')
 async def submit_job(background_tasks: BackgroundTasks, job: JobSubmission):
-    background_tasks.add_task(download_url, job=job)
+    background_tasks.add_task(download_package, job=job)
     return {'status': 'good'}
